@@ -7,13 +7,6 @@ MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
-
-    wallColor =0;
-    fieldColor  =0;
-    playerColor =0;
-    boxColor =0;
-    destinationColor =0;
-
     int levels[10][16][16] = {
         {	//LEVEL 1
                 {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
@@ -198,9 +191,7 @@ MainWindow::MainWindow(QWidget *parent)
     };
 
     moves=0;
-    currentLevel=1-1;
-    playerCurrentX = 5;
-    playerCurrentY = 7;
+    currentLevel=0;
 
     for (int n = 0; n < 10; ++n) {
         for (int x = 0; x < 16; ++x) {
@@ -209,10 +200,10 @@ MainWindow::MainWindow(QWidget *parent)
                 if (n==currentLevel){
                     currentContent[x][y]=levels[n][x][y];
                     resetContent[x][y]=levels[n][x][y];
-                    /* if (currentContent[x][y] ==6 || currentContent[x][y] ==7){
+                     if (currentContent[x][y] ==6 || currentContent[x][y] ==7){
                         playerCurrentX = x;
                         playerCurrentY = y;
-                    }*/
+                    }
                 }
             }
         }
@@ -294,6 +285,24 @@ void MainWindow::showExpanded()
 #endif
 }
 
+void MainWindow::randomColors(){
+
+    srand (QTime::currentTime().msec());
+
+    wallColor  = rand() % 10;
+    srand (QTime::currentTime().msec());
+
+    fieldColor = rand() % 2;
+    srand (QTime::currentTime().msec());
+
+    playerColor = rand() % 2;
+    srand (QTime::currentTime().msec());
+
+    boxColor = rand() % 2;
+    srand (QTime::currentTime().msec());
+
+    destinationColor = rand() % 3;
+}
 
 void MainWindow::drawLevel(){
     /*
@@ -335,6 +344,7 @@ void MainWindow::drawLevel(){
 }
 
 void MainWindow::isWinner(){
+    this->repaint();
     ui->lblMoves->setText("Moves "+QString::number(moves)+"");
     int boxesNotCompleted = 0;
 
@@ -348,27 +358,31 @@ void MainWindow::isWinner(){
     if (boxesNotCompleted == 0){
         ui->lblMoves->setText("Level Completed");
         this->repaint();
-        incLevel();
+        if (currentLevel<9){
+            incLevel();
+        }else{
+            ui->lblMoves->setText("Game finished");
+        }
     }
 }
 
 void MainWindow::incLevel(){
     moves=0;
-    if	(currentLevel < 10){
-        currentLevel = currentLevel ++;
-        //resetContent = currentContent; //?
-        for (int i=0;i<16;i++){
-            for (int j=0;j<16;j++){
-                currentContent[i][j] = levels[currentLevel][i][j];
-                resetContent[i][j] = levels[currentLevel][i][j];
-                if (currentContent[i][j] ==6 || currentContent[i][j] ==7){
-                    playerCurrentX = i;
-                    playerCurrentY = j;
-                }
+    randomColors();
+    currentLevel = currentLevel ++;
+    //resetContent = currentContent; //?
+    for (int i=0;i<16;i++){
+        for (int j=0;j<16;j++){
+            currentContent[i][j] = levels[currentLevel][i][j];
+            resetContent[i][j] = levels[currentLevel][i][j];
+            if (currentContent[i][j] ==6 || currentContent[i][j] ==7){
+                playerCurrentX = i;
+                playerCurrentY = j;
             }
         }
-        drawLevel();
     }
+    drawLevel();
+
 }
 
 void MainWindow::on_btnLeft_pressed(){
@@ -998,7 +1012,8 @@ void MainWindow::on_btnReset_pressed(){
 }
 
 void MainWindow::on_btnClose_pressed(){
-    exit(0);
+ //   exit(0);
+    showNormal();
 }
 
 void MainWindow::on_actionUp_triggered()
